# API Reference

This section contains the API reference for the `bessaplots` library. It provides detailed information about the classes, functions, and modules available in the package.

::: bessaplots